-- BatmanStoreFilter
--  (trtt)
--
--
--        _==/          i     i          \==_
--      /XX/            |\___/|            \XX\
--    /XXXX\            |XXXXX|            /XXXX\
--   |XXXXXX\_         _XXXXXXX_         _/XXXXXX|
--  XXXXXXXXXXXxxxxxxxXXXXXXXXXXXxxxxxxxXXXXXXXXXXX
-- |XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX|
-- XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX
-- |XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX|
--  XXXXXX/^^^^"\XXXXXXXXXXXXXXXXXXXXX/^^^^^\XXXXXX
--   |XXX|       \XXX/^^\XXXXX/^^\XXX/       |XXX|
--     \XX\       \X/    \XXX/    \X/       /XX/
--        "\       "      \X/      "      /"
--
--

local BatmanFilter = ZO_TradingHouseMultiFilter:Subclass()

function BatmanFilter:New(...)
    return ZO_TradingHouseMultiFilter.New(self, ...)
end

function BatmanFilter.SortComparer(row1, row2)
  return string.lower(row1[3]) < string.lower(row2[3])
end


function BatmanFilter.Sort(self)
  table.sort(self, BatmanFilter.SortComparer)
end


function BatmanFilter:Initialize(parentControl)
    local control = CreateControlFromVirtual("$(parent)BatmanContainer", parentControl, "TradingHouseSingleComboFilter")
    ZO_TradingHouseMultiFilter.Initialize(self, control)

	local tradeSkill =
	{
		[ITEMTYPE_ALCHEMY_BASE] 				= CRAFTING_TYPE_ALCHEMY,
		[ITEMTYPE_REAGENT] 						= CRAFTING_TYPE_ALCHEMY,
        [ITEMTYPE_BLACKSMITHING_RAW_MATERIAL]	= CRAFTING_TYPE_BLACKSMITHING,
        [ITEMTYPE_BLACKSMITHING_MATERIAL] 		= CRAFTING_TYPE_BLACKSMITHING,
        [ITEMTYPE_BLACKSMITHING_BOOSTER] 		= CRAFTING_TYPE_BLACKSMITHING,
        [ITEMTYPE_CLOTHIER_RAW_MATERIAL] 		= CRAFTING_TYPE_CLOTHIER,
        [ITEMTYPE_CLOTHIER_MATERIAL] 			= CRAFTING_TYPE_CLOTHIER,
        [ITEMTYPE_CLOTHIER_BOOSTER] 			= CRAFTING_TYPE_CLOTHIER,
        [ITEMTYPE_ENCHANTING_RUNE] 				= CRAFTING_TYPE_ENCHANTING,
        [ITEMTYPE_INGREDIENT] 					= CRAFTING_TYPE_PROVISIONING,
        [ITEMTYPE_WOODWORKING_RAW_MATERIAL] 	= CRAFTING_TYPE_WOODWORKING,
        [ITEMTYPE_WOODWORKING_MATERIAL] 		= CRAFTING_TYPE_WOODWORKING,
        [ITEMTYPE_WOODWORKING_BOOSTER] 			= CRAFTING_TYPE_WOODWORKING,
		[ITEMTYPE_SPICE]						= CRAFTING_TYPE_PROVISIONING,
        [ITEMTYPE_RECIPE] 						= CRAFTING_TYPE_PROVISIONING,
		[ITEMTYPE_FLAVORING]					= CRAFTING_TYPE_PROVISIONING
	}

    local typeData =
    {	
		{ nil, nil, "" },
		{ ITEMTYPE_ALCHEMY_BASE, nil},		
		{ ITEMTYPE_REAGENT, nil },		
        { ITEMTYPE_BLACKSMITHING_RAW_MATERIAL, nil },
        { ITEMTYPE_BLACKSMITHING_MATERIAL, nil },
        { ITEMTYPE_BLACKSMITHING_BOOSTER, nil },
        { ITEMTYPE_CLOTHIER_RAW_MATERIAL, nil },
        { ITEMTYPE_CLOTHIER_MATERIAL, nil },
        { ITEMTYPE_CLOTHIER_BOOSTER, nil },
        { ITEMTYPE_ENCHANTING_RUNE, nil },
        { ITEMTYPE_INGREDIENT, nil },
        { ITEMTYPE_WOODWORKING_RAW_MATERIAL, nil },
        { ITEMTYPE_WOODWORKING_MATERIAL, nil  },
        { ITEMTYPE_WOODWORKING_BOOSTER, nil },
        { ITEMTYPE_SCROLL, nil },
        { ITEMTYPE_RECIPE, nil },
		{ ITEMTYPE_FLAVORING, nil },
		{ ITEMTYPE_SPICE, nil },
        { ITEMTYPE_STYLE_MATERIAL, nil },
		{ ITEMTYPE_ARMOR_TRAIT, nil }, 
		{ ITEMTYPE_WEAPON_TRAIT, nil }
    }		
	
	local tradeSkillName, skillType, skillIndex
	for i=2, #typeData, 1 do
		if tradeSkill[typeData[i][1]] ~= nil then
			skillType, skillIndex = GetCraftingSkillLineIndices(tradeSkill[typeData[i][1]])
			tradeSkillName = GetSkillLineInfo(skillType, skillIndex) .. " - "
		else
			tradeSkillName = ""
		end
		typeData[i][3] = zo_strformat("<<C:1>><<C:2>>", tradeSkillName, GetString(_G["SI_ITEMTYPE"..typeData[i][1]]))
	end
	
	BatmanFilter.Sort(typeData)
	
	local typeAll = {}
	typeAll[3] = zo_strformat("<<C:1>>", GetString(_G["SI_TRADING_HOUSE_BROWSE_ITEM_TYPE_ALL_CRAFTING_MATERIALS"]))
	table.insert(typeData, 1, typeAll)

    local function SelectMatType(_, _, entry)
        self.m_craftType = entry.minValue
    end

    ZO_TradingHouse_InitializeRangeComboBox(control:GetNamedChild("Category"), typeData, SelectMatType)
end

function BatmanFilter:ApplyToSearch(search)
    search:SetFilter(TRADING_HOUSE_FILTER_TYPE_ITEM, self.m_craftType)
end

ZO_TradingHouse_RegisterSearchFilter(BatmanFilter, SI_TRADING_HOUSE_BROWSE_ITEM_TYPE_CRAFTING_MATERIALS)
